@@ -28,14 +28,21 @@ selectOccs_MOD <- function(input, output, session, rvs) {
     newPoly <- sp::SpatialPolygons(list(sp::Polygons(list(sp::Polygon(rvs$polySelXY)), ID=rvs$polySelID)))  # create new polygon from coords
     
     intersect <- sp::over(pts, newPoly)
-    ptRemIndex <- as.numeric(which(is.na(intersect)))
+    ptRemIndex <- which(is.na(intersect))
     
-    remIDs <- as.numeric(pts[ptRemIndex,]$occID)
-    
-    occs.sel <- rvs$occs[-ptRemIndex,]
-    
-    rvs %>% writeLog("Removing occurrences with occID = ", remIDs, 
-                     ". Updated data has n = ", nrow(occs.sel), " records.")
-    return(occs.sel)
+    if (length(ptRemIndex) > 0) {
+      ptRemIndex <- as.numeric(ptRemIndex)  
+      remIDs <- as.numeric(pts[ptRemIndex,]$occID)
+      
+      occs.sel <- rvs$occs[-ptRemIndex,]
+      
+      rvs %>% writeLog("Removing occurrences with occID = ", remIDs, 
+                       ". Updated data has n = ", nrow(occs.sel), " records.")      
+      return(occs.sel)
+    } else {
+      rvs %>% writeLog("Please select a subset of points to retain in the analysis.") 
+      polySelX <- polySelY <- NULL
+      return(rvs$occs)
+    }
   })
 }
